==> cupy-8.3.0.tar.gz: cupy-8.3.0/cupy/core/__init__.py <==
from cupy.core import core  # NOQA
from cupy.core import internal  # NOQA


# internal APIs for testing and developement
from cupy.core._accelerator import set_reduction_accelerators  # NOQA
from cupy.core._accelerator import set_routine_accelerators  # NOQA
from cupy.core._accelerator import get_reduction_accelerators  # NOQA
from cupy.core._accelerator import get_routine_accelerators  # NOQA


# import class and function
from cupy.core._kernel import create_ufunc  # NOQA
from cupy.core._kernel import ElementwiseKernel  # NOQA
from cupy.core._kernel import ufunc  # NOQA
from cupy.core._reduction import create_reduction_func  # NOQA
from cupy.core._reduction import ReductionKernel  # NOQA
from cupy.core._routines_binary import bitwise_and  # NOQA
from cupy.core._routines_binary import bitwise_or  # NOQA
from cupy.core._routines_binary import bitwise_xor  # NOQA
from cupy.core._routines_binary import invert  # NOQA
from cupy.core._routines_binary import left_shift  # NOQA
from cupy.core._routines_binary import right_shift  # NOQA
from cupy.core._routines_linalg import _mat_ptrs  # NOQA
from cupy.core._routines_linalg import dot  # NOQA
from cupy.core._routines_linalg import get_compute_type  # NOQA
from cupy.core._routines_linalg import matmul  # NOQA
from cupy.core._routines_linalg import set_compute_type  # NOQA
from cupy.core._routines_linalg import tensordot_core  # NOQA
from cupy.core._routines_logic import create_comparison  # NOQA
from cupy.core._routines_logic import equal  # NOQA
from cupy.core._routines_logic import greater  # NOQA
from cupy.core._routines_logic import greater_equal  # NOQA
from cupy.core._routines_logic import less  # NOQA
from cupy.core._routines_logic import less_equal  # NOQA
from cupy.core._routines_logic import not_equal  # NOQA
from cupy.core._routines_manipulation import array_split  # NOQA
from cupy.core._routines_manipulation import broadcast  # NOQA
from cupy.core._routines_manipulation import broadcast_to  # NOQA
from cupy.core._routines_manipulation import concatenate_method  # NOQA
from cupy.core._routines_manipulation import moveaxis  # NOQA
from cupy.core._routines_manipulation import rollaxis  # NOQA
from cupy.core._routines_manipulation import size  # NOQA'
from cupy.core._routines_math import absolute  # NOQA
from cupy.core._routines_math import add  # NOQA
from cupy.core._routines_math import angle  # NOQA
from cupy.core._routines_math import conjugate  # NOQA
from cupy.core._routines_math import divide  # NOQA
from cupy.core._routines_math import floor_divide  # NOQA
from cupy.core._routines_math import imag  # NOQA
from cupy.core._routines_math import multiply  # NOQA
from cupy.core._routines_math import negative  # NOQA
from cupy.core._routines_math import power  # NOQA
from cupy.core._routines_math import real  # NOQA
from cupy.core._routines_math import remainder  # NOQA
from cupy.core._routines_math import sqrt  # NOQA
from cupy.core._routines_math import subtract  # NOQA
from cupy.core._routines_math import true_divide  # NOQA
from cupy.core._routines_statistics import nanmax  # NOQA
from cupy.core._routines_statistics import nanmin  # NOQA
from cupy.core.core import _internal_ascontiguousarray  # NOQA
from cupy.core.core import _internal_asfortranarray  # NOQA
from cupy.core.core import array  # NOQA
from cupy.core.core import ascontiguousarray  # NOQA
from cupy.core.core import asfortranarray  # NOQA
from cupy.core.core import divmod  # NOQA
from cupy.core.core import elementwise_copy  # NOQA
from cupy.core.core import elementwise_copy_where  # NOQA
from cupy.core.core import ndarray  # NOQA
from cupy.core.dlpack import fromDlpack  # NOQA
from cupy.core.internal import complete_slice  # NOQA
from cupy.core.internal import get_size  # NOQA
from cupy.core.raw import RawKernel  # NOQA
from cupy.core.raw import RawModule  # NOQA

==> cupy-9.0.0rc1.tar.gz: cupy-9.0.0rc1/cupy/core/__init__.py <==
from cupy.core import core  # NOQA
from cupy.core import internal  # NOQA


# internal APIs for testing and developement
from cupy.core._accelerator import set_reduction_accelerators  # NOQA
from cupy.core._accelerator import set_routine_accelerators  # NOQA
from cupy.core._accelerator import get_reduction_accelerators  # NOQA
from cupy.core._accelerator import get_routine_accelerators  # NOQA


# import class and function
from cupy.core._kernel import create_ufunc  # NOQA
from cupy.core._kernel import ElementwiseKernel  # NOQA
from cupy.core._kernel import ufunc  # NOQA
from cupy.core._reduction import create_reduction_func  # NOQA
from cupy.core._reduction import ReductionKernel  # NOQA
from cupy.core._routines_binary import bitwise_and  # NOQA
from cupy.core._routines_binary import bitwise_or  # NOQA
from cupy.core._routines_binary import bitwise_xor  # NOQA
from cupy.core._routines_binary import invert  # NOQA
from cupy.core._routines_binary import left_shift  # NOQA
from cupy.core._routines_binary import right_shift  # NOQA
from cupy.core._routines_linalg import _mat_ptrs  # NOQA
from cupy.core._routines_linalg import dot  # NOQA
from cupy.core._routines_linalg import get_compute_type  # NOQA
from cupy.core._routines_linalg import _matmul  # NOQA
from cupy.core._routines_linalg import set_compute_type  # NOQA
from cupy.core._routines_linalg import tensordot_core  # NOQA
from cupy.core._routines_logic import create_comparison  # NOQA
from cupy.core._routines_logic import equal  # NOQA
from cupy.core._routines_logic import greater  # NOQA
from cupy.core._routines_logic import greater_equal  # NOQA
from cupy.core._routines_logic import less  # NOQA
from cupy.core._routines_logic import less_equal  # NOQA
from cupy.core._routines_logic import not_equal  # NOQA
from cupy.core._routines_manipulation import array_split  # NOQA
from cupy.core._routines_manipulation import broadcast  # NOQA
from cupy.core._routines_manipulation import broadcast_to  # NOQA
from cupy.core._routines_manipulation import concatenate_method  # NOQA
from cupy.core._routines_manipulation import moveaxis  # NOQA
from cupy.core._routines_manipulation import rollaxis  # NOQA
from cupy.core._routines_manipulation import size  # NOQA'
from cupy.core._routines_math import absolute  # NOQA
from cupy.core._routines_math import add  # NOQA
from cupy.core._routines_math import angle  # NOQA
from cupy.core._routines_math import conjugate  # NOQA
from cupy.core._routines_math import divide  # NOQA
from cupy.core._routines_math import floor_divide  # NOQA
from cupy.core._routines_math import imag  # NOQA
from cupy.core._routines_math import multiply  # NOQA
from cupy.core._routines_math import negative  # NOQA
from cupy.core._routines_math import power  # NOQA
from cupy.core._routines_math import real  # NOQA
from cupy.core._routines_math import remainder  # NOQA
from cupy.core._routines_math import sqrt  # NOQA
from cupy.core._routines_math import subtract  # NOQA
from cupy.core._routines_math import true_divide  # NOQA
from cupy.core._routines_statistics import nanmax  # NOQA
from cupy.core._routines_statistics import nanmin  # NOQA
from cupy.core.core import _internal_ascontiguousarray  # NOQA
from cupy.core.core import _internal_asfortranarray  # NOQA
from cupy.core.core import array  # NOQA
from cupy.core.core import ascontiguousarray  # NOQA
from cupy.core.core import asfortranarray  # NOQA
from cupy.core.core import divmod  # NOQA
from cupy.core.core import elementwise_copy  # NOQA
from cupy.core.core import elementwise_copy_where  # NOQA
from cupy.core.core import ndarray  # NOQA
from cupy.core.dlpack import fromDlpack  # NOQA
from cupy.core.internal import complete_slice  # NOQA
from cupy.core.internal import get_size  # NOQA
from cupy.core.raw import RawKernel  # NOQA
from cupy.core.raw import RawModule  # NOQA
